@@ -1,6 +1,7 @@
 import cairo
 import pytest
 import ctypes
+import platform
 
 
 @pytest.fixture
@@ -49,6 +50,7 @@ def test_get_set_operator_limits(context):
         assert context.get_operator() == val
 
 
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_show_text_glyphs():
     surface = cairo.PDFSurface(None, 300, 300)
     context = cairo.Context(surface)
@@ -306,6 +308,7 @@ def test_scale(context):
         context.scale(object(), 0)
 
 
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_select_font_face(context):
     context.select_font_face("")
     with pytest.raises(TypeError):
@@ -458,6 +461,7 @@ def test_text_extents(context):
         context.text_extents()
 
 
+@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_text_path(context):
     context.text_path("foo")
     with pytest.raises(TypeError):
